@@ -61,8 +61,20 @@ type JenkinsSpec struct {
 	// +optional
 	ConfigurationAsCode *Configuration `json:"configurationAsCode,omitempty"`
 
-	// Backup defines configuration of Backup for Jenkins
+	// BackupEnabled defines whether backup feature is enabled
 	BackupEnabled bool `json:"backupEnabled,omitempty"`
+
+	// MetricsEnabled defines whether prometheus metrics are enabled
+	MetricsEnabled bool `json:"metricsEnabled,omitempty"`
+
+	// PersistentSpec
+	PersistentSpec JenkinsPersistentSpec `json:"persistentSpec,omitempty"`
+}
+
+type JenkinsPersistentSpec struct {
+	Enabled          bool   `json:"enabled,omitempty"`
+	StorageClassName string `json:"storageClassName,omitempty"`
+	VolumeSize       string `json:"volumeSize,omitempty"`
 }
 
 // AuthorizationStrategy defines authorization strategy of the operator for the Jenkins API
@@ -386,6 +398,10 @@ type Service struct {
 	// More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
 	Port int32 `json:"port,omitempty"`
 
+	// The PortName that are exposed by this service.
+	// More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
+	PortName string `json:"portName,omitempty"`
+
 	// The port on each node on which this service is exposed when type=NodePort or LoadBalancer.
 	// Usually assigned by the system. If specified, it will be allocated to the service
 	// if unused or else creation of the service will fail.
@@ -443,7 +459,6 @@ type JenkinsStatus struct {
 // +k8s:openapi-gen=true
 // +kubebuilder:object:root=true
 // +kubebuilder:subresource:status
-
 type Jenkins struct {
 	metav1.TypeMeta   `json:",inline"`
 	metav1.ObjectMeta `json:"metadata,omitempty"`
