@@ -27,20 +27,21 @@ import (
 	//	"math/rand"
 
 	"github.com/go-logr/logr"
-	"github.com/jenkinsci/kubernetes-operator/api/v1alpha2"
-	jenkinsclient "github.com/jenkinsci/kubernetes-operator/pkg/client"
-	"github.com/jenkinsci/kubernetes-operator/pkg/configuration"
-	"github.com/jenkinsci/kubernetes-operator/pkg/configuration/base"
-	"github.com/jenkinsci/kubernetes-operator/pkg/configuration/base/resources"
-	"github.com/jenkinsci/kubernetes-operator/pkg/constants"
-	"github.com/jenkinsci/kubernetes-operator/pkg/log"
-	"github.com/jenkinsci/kubernetes-operator/pkg/notifications/event"
-	"github.com/jenkinsci/kubernetes-operator/pkg/notifications/reason"
-	"github.com/jenkinsci/kubernetes-operator/pkg/plugins"
+	"github.com/jenkinsci/jenkins-automation-operator/api/v1alpha2"
+	jenkinsclient "github.com/jenkinsci/jenkins-automation-operator/pkg/client"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/configuration"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/configuration/base"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/configuration/base/resources"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/constants"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/log"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/notifications/event"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/notifications/reason"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/plugins"
 	v1 "k8s.io/api/rbac/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 
 	// routev1 "github.com/openshift/api/route/v1"
+	// monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	conditionsv1 "github.com/openshift/custom-resource-status/conditions/v1"
 	"github.com/pkg/errors"
 	appsv1 "k8s.io/api/apps/v1"
@@ -101,6 +102,7 @@ func (r *JenkinsReconciler) SetupWithManager(mgr ctrl.Manager) error {
 
 // +kubebuilder:rbac:groups=apps;batch;core;extensionsnetworking.k8s.io;packages.operators.coreos.com;policy;rbac.authorization.k8s.io,resources=*,verbs=*
 // +kubebuilder:rbac:groups=apps.openshift.io;core;project.openshift.io;quota.openshift.io;template.openshift.io;route.openshift.io,resources=*,verbs=*
+// +kubebuilder:rbac:groups=security.openshift.io,resources=securitycontextconstraints,verbs=use
 // +kubebuilder:rbac:groups=jenkins.io,resources=jenkins;jenkins/status;jenkins/finalizers,verbs=*
 
 func (r *JenkinsReconciler) Reconcile(request ctrl.Request) (ctrl.Result, error) {
@@ -335,6 +337,52 @@ func (r *JenkinsReconciler) reconcile(ctx context.Context, request ctrl.Request,
 		}
 	}
 
+	persistentSpec := jenkins.Status.Spec.PersistentSpec
+	if persistentSpec.Enabled {
+		storageClassName := "standard"
+		volumeSize := "1Gi"
+
+		if len(persistentSpec.StorageClassName) > 0 {
+			storageClassName = persistentSpec.StorageClassName
+		}
+		if len(persistentSpec.VolumeSize) > 0 {
+			volumeSize = persistentSpec.VolumeSize
+		}
+
+		jenkinsPVCName := request.Name + "-jenkins"
+		pvcNamespacedName := types.NamespacedName{
+			Namespace: request.Namespace,
+			Name:      jenkinsPVCName,
+		}
+
+		jenkinsPVC := &corev1.PersistentVolumeClaim{}
+		err = r.Client.Get(context.TODO(), request.NamespacedName, jenkinsPVC)
+		if err != nil {
+			if apierrors.IsNotFound(err) {
+				logger.Info(fmt.Sprintf("Creating BackupConfig %s in Namespace %s for Jenkins instance %s",
+					pvcNamespacedName.Name,
+					pvcNamespacedName.Namespace,
+					request.Name))
+				jenkinsPVC.Name = request.Name
+				jenkinsPVC.Namespace = request.Namespace
+				jenkinsPVC.Spec.StorageClassName = &storageClassName
+				jenkinsPVC.Spec.AccessModes = []corev1.PersistentVolumeAccessMode{
+					corev1.ReadWriteOnce,
+				}
+				jenkinsPVC.Spec.Resources = corev1.ResourceRequirements{
+					Requests: corev1.ResourceList{
+						corev1.ResourceStorage: resource.MustParse(volumeSize),
+					},
+				}
+
+				err = r.Client.Create(context.TODO(), jenkinsPVC)
+				if err != nil {
+					return ctrl.Result{}, err
+				}
+			}
+		}
+	}
+
 	logger.V(log.VDebug).Info(fmt.Sprintf("setDefaults reported a change: %v", requeue))
 	config := r.newReconcilerConfiguration(jenkins)
 	// Reconcile base configuration
@@ -514,15 +562,17 @@ func (r *JenkinsReconciler) getCalculatedSpec(ctx context.Context, jenkins *v1al
 			serviceType = corev1.ServiceTypeNodePort
 		}
 		calculatedSpec.Service = v1alpha2.Service{
-			Type: serviceType,
-			Port: constants.DefaultHTTPPortInt32,
+			Type:     serviceType,
+			Port:     constants.DefaultHTTPPortInt32,
+			PortName: "web",
 		}
 	}
 	if reflect.DeepEqual(calculatedSpec.JNLPService, v1alpha2.Service{}) {
 		logger.Info("Setting default Jenkins JNLP service")
 		calculatedSpec.JNLPService = v1alpha2.Service{
-			Type: corev1.ServiceTypeClusterIP,
-			Port: constants.DefaultJNLPPortInt32,
+			Type:     corev1.ServiceTypeClusterIP,
+			Port:     constants.DefaultJNLPPortInt32,
+			PortName: "jnlp",
 		}
 	}
 	if len(calculatedSpec.Master.Containers) > 1 {
