@@ -6,8 +6,8 @@ import (
 	"os"
 	"time"
 
-	"github.com/jenkinsci/kubernetes-operator/api/v1alpha2"
-	"github.com/jenkinsci/kubernetes-operator/pkg/constants"
+	"github.com/jenkinsci/jenkins-automation-operator/api/v1alpha2"
+	"github.com/jenkinsci/jenkins-automation-operator/pkg/constants"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/apimachinery/pkg/types"
@@ -150,13 +150,19 @@ func getJenkinsHomePath(jenkins *v1alpha2.Jenkins) string {
 // GetJenkinsMasterPodBaseVolumes returns Jenkins master pod volumes required by operator
 func GetJenkinsMasterPodBaseVolumes(jenkins *v1alpha2.Jenkins) []corev1.Volume {
 	volumes := []corev1.Volume{
-		getEmptyDirVolume(JenkinsHomeVolumeName),
 		getConfigMapVolume(jenkinsScriptsVolumeName, getScriptsConfigMapName(jenkins), 0777),
 		getConfigMapVolume(jenkinsInitConfigurationVolumeName, GetInitConfigurationConfigMapName(jenkins)),
 		getConfigMapVolume(basePluginsVolumeName, GetBasePluginsVolumeNameConfigMapName(jenkins)),
 		getSecretVolume(jenkinsOperatorCredentialsVolumeName, GetOperatorCredentialsSecretName(jenkins)),
 	}
 
+	// Add Volume for Persistence
+	if jenkins.Spec.PersistentSpec.Enabled {
+		volumes = append(volumes, getPVCVolume(JenkinsHomeVolumeName, jenkins.Name))
+	} else {
+		volumes = append(volumes, getEmptyDirVolume(JenkinsHomeVolumeName))
+	}
+
 	if jenkins.Status != nil && jenkins.Status.Spec != nil && jenkins.Status.Spec.ConfigurationAsCode != nil {
 		spec := jenkins.Status.Spec
 		configurationAsCode := spec.ConfigurationAsCode
@@ -601,6 +607,18 @@ func getSecretVolume(volumeName string, secretName string) corev1.Volume {
 	}
 }
 
+func getPVCVolume(volumeName, claimName string) corev1.Volume {
+	return corev1.Volume{
+		Name: volumeName,
+		VolumeSource: corev1.VolumeSource{
+			PersistentVolumeClaim: &corev1.PersistentVolumeClaimVolumeSource{
+				ClaimName: claimName,
+				ReadOnly:  false,
+			},
+		},
+	}
+}
+
 func getSubPathVolumeMount(volumeName string, mountPath string, subPath string, readOnly bool) corev1.VolumeMount {
 	return corev1.VolumeMount{
 		Name:      volumeName,
